(ns tservice.plugins.quartet-rnaseq-report.exp2qcdt
  "A wrapper for exp2qcdt tool."
  (:require [tservice.lib.commons :refer [get-path-variable]]
            [tservice.config :refer [get-plugin-dir]]
            [tservice.lib.fs :as fs]
            [clojure.java.shell :as shell :refer [sh]]))

(defn add-env-to-path
  "Add the path of the plugin's environment into the PATH and return the PATH"
  []
  (let [env-bin-path (fs/join-paths (get-plugin-dir) "plugins" "repository" "quartet-rnaseq-report" "bin")
        path (get-path-variable)]
    (str env-bin-path ":" path)))

(defn call-exp2qcdt!
  "Call exp2qcdt bash script.
   exp-file: FPKM file , each row is the expression values of a gene and each column is a library.
   cnt-file: Count file, each row is the expression values of a gene and each column is a library.
   meta-file: Need to contain three columns: library, group, and sample and library names must be matched with the column names in the `exp-file`.
   result-dir: A directory for result files.
  "
  [exp-file cnt-file meta-file result-dir]
  (shell/with-sh-env {:PATH   (add-env-to-path)
                      :LC_ALL "en_US.utf-8"
                      :LANG   "en_US.utf-8"}
    (let [command ["bash" "-c"
                   (format "exp2qcdt -e %s -c %s -m %s -o %s" exp-file cnt-file meta-file result-dir)]
          result  (apply sh command)
          status (if (= (:exit result) 0) "Success" "Error")
          msg (str (:out result) "\n" (:err result))]
      {:status status
       :msg msg})))

